@@ -11,12 +11,11 @@ import struct
 import timeit
 
 parser = argparse.ArgumentParser(description='Benchmark maxminddb.')
-parser.add_argument('--count', default=250000, type=int,
-                    help='number of lookups')
-parser.add_argument('--mode', default=0, type=int,
-                    help='reader mode to use')
-parser.add_argument('--file', default='GeoIP2-City.mmdb',
-                    help='path to mmdb file')
+parser.add_argument(
+    '--count', default=250000, type=int, help='number of lookups')
+parser.add_argument('--mode', default=0, type=int, help='reader mode to use')
+parser.add_argument(
+    '--file', default='GeoIP2-City.mmdb', help='path to mmdb file')
 
 args = parser.parse_args()
 
@@ -28,8 +27,9 @@ def lookup_ip_address():
     record = reader.get(str(ip))
 
 
-elapsed = timeit.timeit('lookup_ip_address()',
-                        setup='from __main__ import lookup_ip_address',
-                        number=args.count)
+elapsed = timeit.timeit(
+    'lookup_ip_address()',
+    setup='from __main__ import lookup_ip_address',
+    number=args.count)
 
 print(args.count / elapsed, 'lookups per second')
