@@ -4,6 +4,7 @@
 from __future__ import unicode_literals
 
 import logging
+import mock
 import os
 import sys
 import threading
@@ -12,6 +13,8 @@ from multiprocessing import Process, Pipe
 
 import maxminddb
 
+from maxminddb.compat import compat_ip_address
+
 try:
     import maxminddb.extension
 except ImportError:
@@ -20,7 +23,7 @@ except ImportError:
 from maxminddb import open_database, InvalidDatabaseError
 from maxminddb.compat import FileNotFoundError
 from maxminddb.const import (MODE_AUTO, MODE_MMAP_EXT, MODE_MMAP, MODE_FILE,
-                             MODE_MEMORY)
+                             MODE_MEMORY, MODE_FD)
 
 if sys.version_info[:2] == (2, 6):
     import unittest2 as unittest
@@ -32,6 +35,18 @@ if sys.version_info[0] == 2:
     unittest.TestCase.assertRegex = unittest.TestCase.assertRegexpMatches
 
 
+def get_reader_from_file_descriptor(filepath, mode):
+    """Patches open_database() for class TestFDReader()."""
+    if mode == MODE_FD:
+        with open(filepath, 'rb') as mmdb_fh:
+            return maxminddb.open_database(mmdb_fh, mode)
+    else:
+        # There are a few cases where mode is statically defined in
+        # BaseTestReader(). In those cases just call an unpatched
+        # open_database() with a string path.
+        return maxminddb.open_database(filepath, mode)
+
+
 class BaseTestReader(object):
     def test_reader(self):
         for record_size in [24, 28, 32]:
@@ -97,11 +112,22 @@ class BaseTestReader(object):
     def test_no_extension_exception(self):
         real_extension = maxminddb.extension
         maxminddb.extension = None
-        with self.assertRaisesRegex(ValueError, 'MODE_MMAP_EXT requires the maxminddb.extension module to be available'):
-            open_database(
-            'tests/data/test-data/MaxMind-DB-test-decoder.mmdb', MODE_MMAP_EXT)
+        with self.assertRaisesRegex(
+                ValueError,
+                'MODE_MMAP_EXT requires the maxminddb.extension module to be available'
+        ):
+            open_database('tests/data/test-data/MaxMind-DB-test-decoder.mmdb',
+                          MODE_MMAP_EXT)
         maxminddb.extension = real_extension
 
+    def test_ip_object_lookup(self):
+        reader = open_database('tests/data/test-data/GeoIP2-City-Test.mmdb',
+                               self.mode)
+        with self.assertRaisesRegex(
+                TypeError, "must be str(?:ing)?, not IPv6Address"):
+            reader.get(compat_ip_address('2001:220::'))
+        reader.close()
+
     def test_broken_database(self):
         reader = open_database('tests/data/test-data/'
                                'GeoIP2-City-Test-Broken-Double-Format.mmdb',
@@ -149,7 +175,10 @@ class BaseTestReader(object):
         cls = self.readerClass[0]
         self.assertRaisesRegex(
             TypeError,
-            ' 1 required positional argument|\(pos 1\) not found|takes at least 2 arguments',
+            ' 1 required positional argument|'
+            '\(pos 1\) not found|'
+            'takes at least 2 arguments|'
+            'function missing required argument \'database\' \(pos 1\)',
             cls)
 
     def test_too_many_get_args(self):
@@ -192,7 +221,7 @@ class BaseTestReader(object):
                           'Double close does not throw an exception')
 
     def test_closed_get(self):
-        if self.mode == MODE_MEMORY:
+        if self.mode in [MODE_MEMORY, MODE_FD]:
             return
         reader = open_database(
             'tests/data/test-data/MaxMind-DB-test-decoder.mmdb', self.mode)
@@ -216,10 +245,10 @@ class BaseTestReader(object):
             with reader:
                 pass
 
-        self.assertRaisesRegex(ValueError, 'Attempt to reopen a closed MaxMind DB',
+        self.assertRaisesRegex(ValueError,
+                               'Attempt to reopen a closed MaxMind DB',
                                use_with, reader)
 
-
     def test_closed(self):
         reader = open_database(
             'tests/data/test-data/MaxMind-DB-test-decoder.mmdb', self.mode)
@@ -227,7 +256,6 @@ class BaseTestReader(object):
         reader.close()
         self.assertEqual(reader.closed, True)
 
-
     # XXX - Figure out whether we want to have the same behavior on both the
     #       extension and the pure Python reader. If we do, the pure Python
     #       reader will need to throw an exception or the extension will need
@@ -379,8 +407,8 @@ def has_maxminddb_extension():
     return maxminddb.extension and hasattr(maxminddb.extension, 'Reader')
 
 
-@unittest.skipIf(not has_maxminddb_extension() and
-                 not os.environ.get('MM_FORCE_EXT_TESTS'),
+@unittest.skipIf(not has_maxminddb_extension()
+                 and not os.environ.get('MM_FORCE_EXT_TESTS'),
                  'No C extension module found. Skipping tests')
 class TestExtensionReader(BaseTestReader, unittest.TestCase):
     mode = MODE_MMAP_EXT
@@ -413,6 +441,17 @@ class TestMemoryReader(BaseTestReader, unittest.TestCase):
     readerClass = [maxminddb.reader.Reader]
 
 
+class TestFDReader(BaseTestReader, unittest.TestCase):
+    def setUp(self):
+        self.open_database_patcher = mock.patch('reader_test.open_database')
+        self.addCleanup(self.open_database_patcher.stop)
+        self.open_database = self.open_database_patcher.start()
+        self.open_database.side_effect = get_reader_from_file_descriptor
+
+    mode = MODE_FD
+    readerClass = [maxminddb.reader.Reader]
+
+
 class TestOldReader(unittest.TestCase):
     def test_old_reader(self):
         reader = maxminddb.Reader(
